#!/bin/ksh
#
# Illustrate a strange problem which occurs when definitions are imported from
# a .ao file (or a .al library), but not when they are made directly.
#
mkdir bug-library
cd bug-library
axiomxl -V -Fao ../bug-library-countable.as
axiomxl -V -Ginterp ../bug-library.as
axiomxl -V -Ginterp -DLIB ../bug-library.as
cd ..